@@ -1,59 +1,58 @@
 
 # Grow-Shrink frontend.
 gs = function(x, cluster = NULL, whitelist = NULL, blacklist = NULL,
-    test = NULL, alpha = 0.05, debug = FALSE, optimized = TRUE,
-    strict = FALSE, undirected = FALSE, direction = FALSE) {
+    test = NULL, alpha = 0.05, B = NULL, debug = FALSE, optimized = TRUE,
+    strict = FALSE, undirected = FALSE) {
 
   bnlearn(x = x, cluster = cluster, whitelist = whitelist,
-    blacklist = blacklist, test = test, alpha = alpha, debug = debug,
-    optimized = optimized, strict = strict, undirected = undirected,
-    direction = direction)
+    blacklist = blacklist, test = test, alpha = alpha, B = B, debug = debug,
+    optimized = optimized, strict = strict, undirected = undirected)
 
 }#GS
 
 # Incremental Association frontend.
 iamb = function(x, cluster = NULL, whitelist = NULL, blacklist = NULL,
-    test = NULL, alpha = 0.05, debug = FALSE, optimized = TRUE,
-    strict = FALSE, undirected = FALSE, direction = FALSE) {
+    test = NULL, alpha = 0.05, B = NULL, debug = FALSE, optimized = TRUE,
+    strict = FALSE, undirected = FALSE) {
 
   bnlearn(x = x, cluster = cluster, whitelist = whitelist,
-    blacklist = blacklist, test = test, alpha = alpha, method = "iamb",
+    blacklist = blacklist, test = test, alpha = alpha, B = B, method = "iamb",
     debug = debug, optimized = optimized, strict = strict,
-    undirected = undirected, direction = direction)
+    undirected = undirected)
 
 }#IAMB
 
 # Fast-IAMB frontend.
 fast.iamb = function(x, cluster = NULL, whitelist = NULL, blacklist = NULL,
-    test = NULL, alpha = 0.05, debug = FALSE, optimized = TRUE,
-    strict = FALSE, undirected = FALSE, direction = FALSE) {
+    test = NULL, alpha = 0.05, B = NULL, debug = FALSE, optimized = TRUE,
+    strict = FALSE, undirected = FALSE) {
 
   bnlearn(x = x, cluster = cluster, whitelist = whitelist,
-    blacklist = blacklist, test = test, alpha = alpha,
+    blacklist = blacklist, test = test, alpha = alpha, B = B,
     method = "fast-iamb", debug = debug, optimized = optimized,
-    strict = strict, undirected = undirected, direction = direction)
+    strict = strict, undirected = undirected)
 
 }#FAST.IAMB
 
 # Inter-IAMB frontend.
 inter.iamb = function(x, cluster = NULL, whitelist = NULL, blacklist = NULL,
-    test = NULL, alpha = 0.05, debug = FALSE, optimized = TRUE,
-    strict = FALSE, undirected = FALSE, direction = FALSE) {
+    test = NULL, alpha = 0.05, B = NULL, debug = FALSE, optimized = TRUE,
+    strict = FALSE, undirected = FALSE) {
 
   bnlearn(x = x, cluster = cluster, whitelist = whitelist,
-    blacklist = blacklist, test = test, alpha = alpha,
+    blacklist = blacklist, test = test, alpha = alpha, B = B,
     method = "inter-iamb", debug = debug, optimized = optimized,
-    strict = strict, undirected =  undirected, direction = direction)
+    strict = strict, undirected =  undirected)
 
 }#INTER.IAMB
 
 # MMPC frontend.
 mmpc = function(x, cluster = NULL, whitelist = NULL, blacklist = NULL,
-    test = NULL, alpha = 0.05, debug = FALSE, optimized = TRUE,
+    test = NULL, alpha = 0.05, B = NULL, debug = FALSE, optimized = TRUE,
     strict = FALSE) {
 
   bnlearn(x = x, cluster = cluster, whitelist = whitelist,
-    blacklist = blacklist, test = test, alpha = alpha,
+    blacklist = blacklist, test = test, alpha = alpha, B = B,
     method = "mmpc", debug = debug, optimized = optimized,
     strict = strict, undirected = TRUE)
 
