@@ -1,14 +1,11 @@
 
-#include <R.h>
-#include <Rinternals.h>
-
-#define INT(x) INTEGER(x)[0]
-#define NUM(x) REAL(x)[0]
+#include "common.h"
 
+/* unconditional mutual information, to be used for the asymptotic test. */
 SEXP mi (SEXP x, SEXP y, SEXP lx, SEXP ly, SEXP length) {
 
   int i = 0, j = 0, k = 0;
-  unsigned int **n, *ni, *nj;
+  int **n, *ni, *nj;
   SEXP result;
 
   PROTECT(result = allocVector(REALSXP, 1));
@@ -16,20 +13,10 @@ SEXP mi (SEXP x, SEXP y, SEXP lx, SEXP ly, SEXP length) {
   /* initialize result to zero. */
   NUM(result) = 0;
 
-  /* initialize the contingency table. */
-  n = (unsigned int **) R_alloc(INT(lx), sizeof(int *));
-  for (i = 0; i < INT(lx); i++) {
-
-    n[i] = (unsigned int *) R_alloc(INT(ly), sizeof(int));
-    memset(n[i], '\0', sizeof(int) * INT(ly));
-
-  }/*FOR*/
-
-  /* initialize the marginal frequencies. */
-  ni = (unsigned int *) R_alloc(INT(lx), sizeof(int));
-  memset(ni, '\0', sizeof(int) * INT(lx));
-  nj = (unsigned int *) R_alloc(INT(ly), sizeof(int));
-  memset(nj, '\0', sizeof(int) * INT(ly));
+  /* initialize the contingency table and the marginal frequencies. */
+  n = alloc2dcont(INT(lx), INT(ly));
+  ni = alloc1dcont(INT(lx));
+  nj = alloc1dcont(INT(ly));
 
   /* compute the joint frequency of x and y. */
   for (k = 0; k < INT(length); k++) {
@@ -58,10 +45,11 @@ SEXP mi (SEXP x, SEXP y, SEXP lx, SEXP ly, SEXP length) {
 
 }/*MI*/
 
+/* conditional mutual information, to be used for the asymptotic test. */
 SEXP cmi (SEXP x, SEXP y, SEXP z, SEXP lx, SEXP ly, SEXP lz, SEXP length) {
 
   int i = 0, j = 0, k = 0;
-  unsigned int ***n, **ni, **nj, *nk;
+  int ***n, **ni, **nj, *nk;
   SEXP result;
 
   PROTECT(result = allocVector(REALSXP, 1));
@@ -69,40 +57,11 @@ SEXP cmi (SEXP x, SEXP y, SEXP z, SEXP lx, SEXP ly, SEXP lz, SEXP length) {
   /* initialize result to zero. */
   NUM(result) = 0;
 
-  /* initialize the contingency table. */
-  n = (unsigned int ***) R_alloc(INT(lx), sizeof(int *));
-  for (i = 0; i < INT(lx); i++) {
-
-    n[i] = (unsigned int **) R_alloc(INT(ly), sizeof(int *));
-
-    for (j = 0; j < INT(ly); j++) {
-
-      n[i][j] = (unsigned int*) R_alloc(INT(lz), sizeof(int));
-      memset(n[i][j], '\0', sizeof(int) * INT(lz));
-
-    }/*FOR*/
-
-  }/*FOR*/
-
-  /* initialize the marginal frequencies. */
-  ni = (unsigned int **) R_alloc(INT(lx), sizeof(int *));
-  for (i = 0; i < INT(lx); i++) {
-
-    ni[i] = (unsigned int *) R_alloc(INT(lz), sizeof(int));
-    memset(ni[i], '\0', sizeof(int) * INT(lz));
-
-  }/*FOR*/
-
-  nj = (unsigned int **) R_alloc(INT(ly), sizeof(int *));
-  for (i = 0; i < INT(ly); i++) {
-
-    nj[i] = (unsigned int *) R_alloc(INT(lz), sizeof(int));
-    memset(nj[i], '\0', sizeof(int) * INT(lz));
-
-  }/*FOR*/
-
-  nk = (unsigned int *) R_alloc(INT(lz), sizeof(int));
-  memset(nk, '\0', sizeof(int) * INT(lz));
+  /* initialize the contingency table and the marginal frequencies. */
+  n = alloc3dcont(INT(lx), INT(ly), INT(lz));
+  ni = alloc2dcont(INT(lx), INT(lz));
+  nj = alloc2dcont(INT(ly), INT(lz));
+  nk = alloc1dcont(INT(lz));
 
   /* compute the joint frequency of x, y, and z. */
   for (k = 0; k < INT(length); k++) {
